# Constraint

The Constraint commands define constraints between regions of the model.

## Create constraints

```{eval-rst}
.. autoclass:: abaqus.Constraint.ConstraintModel.ConstraintModel
    :members:
    :show-inheritance:

    .. autoclasstoc::

```

## Other Classes

```{eval-rst}

.. toggle::

    .. automembers:: abaqus.Constraint
        :recursive:
        :exclude: ConstraintModel

    .. placeholder for empty members
```
